Lorina readers
--------------

The mockturtle library implements several reader callbacks that can be used
with the lorina_ library.  The header ``mockturtle/io/<format>_reader.hpp``
implements the reader callback ``<format>_reader``.

.. _lorina: https://github.com/hriener/lorina

.. doxygenclass:: mockturtle::aiger_reader

.. doxygenclass:: mockturtle::bench_reader

.. doxygenclass:: mockturtle::blif_reader

.. doxygenclass:: mockturtle::pla_reader

.. doxygenclass:: mockturtle::verilog_reader

.. doxygenclass:: mockturtle::genlib_reader

.. doxygenclass:: mockturtle::super_reader
